@@ -8,14 +8,32 @@ import sys
 
 import unittest
 from pathlib import Path
-sys.path.insert(0, str(Path(__file__).resolve().parent))
 from tempfile import TemporaryDirectory
-from asyncinotify import Event, Inotify, Mask, InotifyError
+from asyncinotify import Event, Inotify, Mask
+
+if sys.version_info[1] > 8:
+    from collections.abc import Sequence
+else:
+    from typing import Sequence
+
 import asyncio
+try:
+    from asyncio import run
+except ImportError:
+    def run(main): # type: ignore
+        loop = asyncio.new_event_loop()
+        asyncio.set_event_loop(loop)
+        try:
+            try:
+                return loop.run_until_complete(main)
+            finally:
+                loop.run_until_complete(loop.shutdown_asyncgens())
+        finally:
+            loop.close()
 
 class TestInotify(unittest.TestCase):
 
-    async def watch_events(self):
+    async def watch_events(self) -> Sequence[Event]:
         '''Watch events until an IGNORED is received for the main watch, then
         return the events.'''
         events = []
@@ -25,7 +43,9 @@ class TestInotify(unittest.TestCase):
                 if Mask.IGNORED in event and event.watch is self.watch:
                     return events
 
-    def gather_events(self, function) -> list[Event]:
+        raise RuntimeError()
+
+    def gather_events(self, function) -> Sequence[Event]:
         '''Run the function "soon" in the event loop, and also watch events
         until you can return the result.'''
 
@@ -34,7 +54,7 @@ class TestInotify(unittest.TestCase):
         finally:
             self.inotify.rm_watch(self.watch)
 
-        return asyncio.run(self.watch_events())
+        return run(self.watch_events())
 
     def setUp(self):
         self._dir = TemporaryDirectory()
@@ -127,14 +147,14 @@ class TestInotify(unittest.TestCase):
         # Will not raise error
         self.inotify.add_watch(self.dir / 'foo', Mask.ATTRIB)
 
-        with self.assertRaises(InotifyError):
+        with self.assertRaises(OSError):
             self.inotify.add_watch(self.dir / 'foo', Mask.ATTRIB | Mask.ONLYDIR)
 
     def test_nonexist_error(self):
-        with self.assertRaises(InotifyError):
+        with self.assertRaises(OSError):
             self.inotify.add_watch(self.dir / 'foo', Mask.ATTRIB | Mask.ONLYDIR)
 
-        with self.assertRaises(InotifyError):
+        with self.assertRaises(OSError):
             self.inotify.add_watch(self.dir / 'foo', Mask.ATTRIB)
 
     def test_move_self(self):
@@ -185,7 +205,7 @@ class TestInotify(unittest.TestCase):
 
 class TestSyncInotify(unittest.TestCase):
 
-    def watch_events(self):
+    def watch_events(self) -> Sequence[Event]:
         '''Watch events until an IGNORED is received for the main watch, then
         return the events.'''
         events = []
@@ -194,8 +214,9 @@ class TestSyncInotify(unittest.TestCase):
                 events.append(event)
                 if Mask.IGNORED in event and event.watch is self.watch:
                     return events
+        raise RuntimeError()
 
-    def gather_events(self, function):
+    def gather_events(self, function) -> Sequence[Event]:
         '''Run the function and then watch events until you can return the
         result.'''
 
@@ -297,14 +318,14 @@ class TestSyncInotify(unittest.TestCase):
         # Will not raise error
         self.inotify.add_watch(self.dir / 'foo', Mask.ATTRIB)
 
-        with self.assertRaises(InotifyError):
+        with self.assertRaises(OSError):
             self.inotify.add_watch(self.dir / 'foo', Mask.ATTRIB | Mask.ONLYDIR)
 
     def test_nonexist_error(self):
-        with self.assertRaises(InotifyError):
+        with self.assertRaises(OSError):
             self.inotify.add_watch(self.dir / 'foo', Mask.ATTRIB | Mask.ONLYDIR)
 
-        with self.assertRaises(InotifyError):
+        with self.assertRaises(OSError):
             self.inotify.add_watch(self.dir / 'foo', Mask.ATTRIB)
 
     def test_move_self(self):
@@ -353,5 +374,14 @@ class TestSyncInotify(unittest.TestCase):
         self.assertFalse(any(Mask.DELETE in event and event.name is None for event in events))
         # There may or may not be an IGNORED for the watch as well
 
+    def test_timeout(self):
+        with self.inotify as inotify:
+            inotify.sync_timeout = 0.1
+            list(self.dir.iterdir())
+            self.assertTrue(inotify.sync_get())
+            for event in inotify:
+                pass
+            self.assertFalse(inotify.sync_get())
+
 if __name__ == '__main__':
     unittest.main()
